@@ -122,6 +122,18 @@ impl<const L: usize> PartialEq<&str> for String<L> {
     }
 }
 
+impl<const L: usize> PartialEq<String<L>> for &str {
+    #[inline]
+    fn eq(&self, other: &String<L>) -> bool {
+        PartialEq::eq(&self[..], &other[..])
+    }
+
+    #[inline]
+    fn ne(&self, other: &String<L>) -> bool {
+        PartialEq::ne(&self[..], &other[..])
+    }
+}
+
 impl<const L: usize> ops::Index<ops::Range<usize>> for String<L> {
     type Output = str;
 
@@ -227,7 +239,7 @@ mod tests {
         let s_ = "abcde";
         let s = String::<5>::try_from(s_).unwrap();
 
-        assert_eq!(s, s_);
+        assert_eq!(s_, s);
     }
 
     #[test]
